Stan Math Library: stan/math/prim/arr/fun/rep_array.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
rep_array.hpp File Reference
`#include <stan/math/prim/scal/err/check_nonnegative.hpp>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
std::vector< T > | stan::math::rep_array (const T &x, int n)
template<typename T >
std::vector< std::vector< T > > | stan::math::rep_array (const T &x, int m, int n)
template<typename T >
std::vector< std::vector< std::vector< T > > > | stan::math::rep_array (const T &x, int k, int m, int n)

[ Stan Home Page ] © 2011–2016, Stan Development Team.